from django.contrib import admin
from edt.models import Timetable, LastUpdate, Group, Subscription, Room, Course


@admin.register(Timetable)
class TimetableAdmin(admin.ModelAdmin):
    prepopulated_fields = {"slug": ("name",)}
    list_display = ("name", "url",)


@admin.register(LastUpdate)
class LastUpdateAdmin(admin.ModelAdmin):
    list_display = ("timetable", "week", "year", "date",)
    list_filter = ("timetable__name",)


@admin.register(Group)
class GroupAdmin(admin.ModelAdmin):
    fieldsets = (
        (None, {"fields": ("name", "timetable",)}),
        ("Groupes", {"fields": ("mention", "subgroup", "td", "tp",)}),)
    list_display = ("name", "timetable",)
    list_filter = ("timetable__name",)
    readonly_fields = ("mention", "subgroup", "td", "tp",)


@admin.register(Subscription)
class SubscriptionAdmin(admin.ModelAdmin):
    list_display = ("email", "group", "active",)
    readonly_fields = ("token",)


@admin.register(Room)
class RoomAdmin(admin.ModelAdmin):
    pass


@admin.register(Course)
class CourseAdmin(admin.ModelAdmin):
    fieldsets = (
        (None, {"fields": ("name", "type", "timetable", "groups", "rooms",)}),
        ("Horaires", {"fields": ("begin", "end",)}),
        ("Remarques", {"fields": ("notes",)}),)
    list_display = ("name", "type", "timetable", "begin", "end",)
    list_filter = ("type", "timetable__name", "groups",)
    ordering = ("begin",)
